@@ -1,22 +1,20 @@
 #' Application User-Interface
 #'
 #' @noRd
-#' @importFrom shiny addResourcePath fluidPage tags fluidRow span icon strong a sidebarLayout sidebarPanel div tabsetPanel tabPanel mainPanel
-
 app_ui <- function() {
 
   # Add www/ directory to resource path (deployment)
-  addResourcePath(prefix = "www", directoryPath = system.file("www", package = "mapmixture"))
+  shiny::addResourcePath(prefix = "www", directoryPath = system.file("www", package = "mapmixture"))
 
   # Add www/ directory to resource path (developer mode)
-  # addResourcePath(prefix = "www", directoryPath = "./inst/www/")
+  # shiny::addResourcePath(prefix = "www", directoryPath = "./inst/www/")
 
   # App UI
-  fluidPage(
+  shiny::fluidPage(
 
     # Link to external CSS
-    tags$head(
-      tags$link(rel = "stylesheet", type = "text/css", href = "www/styles.css")
+    shiny::tags$head(
+      shiny::tags$link(rel = "stylesheet", type = "text/css", href = "www/styles.css")
     ),
 
     # Enable dependencies
@@ -28,33 +26,33 @@ app_ui <- function() {
     theme = bslib::bs_theme(version = 5, bootswatch = "flatly"),
 
     # Navbar with title and links ----
-    fluidRow(
+    shiny::fluidRow(
       class = "custom-navbar",
       style = "background: #18bc9c; color: white; padding: 10px; margin-bottom: 5px;",
-      span(
-        span(icon("chart-pie", style = "margin-right: 5px;"), strong("mapmixture"), span(class = "badge bg-light mx-1", "1.1.2")),
-        a(
+      shiny::span(
+        shiny::span(shiny::icon("chart-pie", style = "margin-right: 5px;"), shiny::strong("mapmixture"), shiny::span(class = "badge bg-light mx-1", "1.1.2")),
+        shiny::a(
           style = "color: white;",
           href = "https://twitter.com/tom__jenkins",
           target = "_blank",
-          span(style = "float: right;", icon("twitter", style = "margin-right: 5px;"), "Twitter"),
+          shiny::span(style = "float: right;", shiny::icon("twitter", style = "margin-right: 5px;"), "Twitter"),
         ),
-        a(
+        shiny::a(
           style = "color: white;",
           href = "https://github.com/Tom-Jenkins/mapmixture",
           target = "_blank",
-          span(style = "float: right; margin-right: 20px;", icon("github", style = "margin-right: 5px;"), "GitHub")),
+          shiny::span(style = "float: right; margin-right: 20px;", shiny::icon("github", style = "margin-right: 5px;"), "GitHub")),
       ),
     ),
 
     # Sidebar layout with inputs (left) and outputs (right) ----
-    sidebarLayout(
+    shiny::sidebarLayout(
 
       # Sidebar panel for inputs ----
-      sidebarPanel(
+      shiny::sidebarPanel(
         class = "sidebar-container",
 
-        div(
+        shiny::div(
           class = "sidebar-nonparam-container",
 
           # File upload UI module ----
@@ -65,19 +63,19 @@ app_ui <- function() {
         ),
 
         # Tab panel for map and bar chart input parameters ----
-        span(class = "nav-justified",
-          tabsetPanel(
+        shiny::span(class = "nav-justified",
+                    shiny::tabsetPanel(
             type = "pills",
             id = "options-pills-container",
             # Map parameters
-            tabPanel(
+            shiny::tabPanel(
               class = "parameter-options-container primary",
               title = "Map Options",
               mod_map_params_ui("map_params")
               # map_params_module$ui(ns("map_params_module")),
             ),
             # Barplot parameters
-            tabPanel(
+            shiny::tabPanel(
               class = "parameter-options-container",
               title = "Barplot Options",
               mod_barplot_params_ui("barplot_params")
@@ -87,34 +85,34 @@ app_ui <- function() {
       ),
 
       # Main panel for displaying outputs ----
-      mainPanel(
-        tabsetPanel(
+      shiny::mainPanel(
+        shiny::tabsetPanel(
           id = "app-tabset-panel",
-          tabPanel(
+          shiny::tabPanel(
             title = "Admixture Map",
-            icon = icon("earth-europe"),
+            icon = shiny::icon("earth-europe"),
             mod_main_plot_ui("main_plot")
           ),
-          tabPanel(
+          shiny::tabPanel(
             title = "Structure Plot",
-            icon = icon("chart-simple"),
+            icon = shiny::icon("chart-simple"),
             mod_barplot_plot_ui("bar_plot")
           ),
-          tabPanel(
+          shiny::tabPanel(
             title = "File Format",
-            icon = icon("file"),
+            icon = shiny::icon("file"),
             file_format_content(),
-            br(),
+            shiny::br(),
           ),
-          tabPanel(
+          shiny::tabPanel(
             title = "Gallery",
-            icon = icon("image"),
+            icon = shiny::icon("image"),
             gallery_content(),
-            br(),
+            shiny::br(),
           ),
-          tabPanel(
+          shiny::tabPanel(
             title = "About",
-            icon = icon("circle-question"),
+            icon = shiny::icon("circle-question"),
             about_content(),
           ),
         )
@@ -123,6 +121,6 @@ app_ui <- function() {
     ),
 
     # Link to external JavaScript
-    tags$script(src = "www/script.js")
+    shiny::tags$script(src = "www/script.js")
   )
 }
