@@ -18,7 +18,7 @@
 #' @param basemap SpatRaster or sf object to use as the basemap. A SpatRaster object can be created from a file
 #' using the `terra::rast()` function. A sf object can be created from a file
 #' using the `sf::st_read()` function. If `NULL`, world country boundaries are used.
-#' @param pie_size numeric value of zero or greater.
+#' @param pie_size vector of numeric values of zero or greater. Can be a single value or a vector the same length as the number of sites.
 #' @param pie_border numeric value of zero or greater.
 #' @param pie_border_col string denoting colour of pie border.
 #' @param pie_opacity numeric value of zero to one.
@@ -93,7 +93,7 @@
 mapmixture <- function(
   # Data input
   admixture_df, coords_df,
-  # Parameter arguments
+  # Arguments
   cluster_cols = NULL, cluster_names = NULL,
   boundary = NULL, crs = 4326, basemap = NULL,
   pie_size = 1, pie_border = 0.2, pie_border_col = "black", pie_opacity = 1,
@@ -123,8 +123,8 @@ mapmixture <- function(
   #     stop("Error downloading data from Natural Earth. Please check internet connection.")
   # })
 
-  # Cluster column order
-  cluster_col_order <- colnames(admixture_df)[3:ncol(admixture_df)]
+  # Vector of cluster column names
+  cluster_col_names <- colnames(admixture_df)[3:ncol(admixture_df)]
 
   # Standardise input data ----
   tryCatch({
@@ -137,7 +137,12 @@ mapmixture <- function(
 
   # Check coordinate site IDs exactly match admixture site IDs
   if ( all(coords_df[[1]] == unique(admixture_df[[1]])) == FALSE ) {
-    stop("Site names in coordinates data frame do not match site names in admixture data frame. Check site names are not empty or NA and that they match.")
+    stop("Invalid input: site names in coordinates data frame do not match site names in admixture data frame. Check site names are not empty or NA and that they match.")
+  }
+
+  # Check if pie_size vector is not 1 and if pie_size is not the same length as the number of sites
+  if ( length(pie_size) != 1 & length(pie_size) != dplyr::n_distinct(admixture_df[[1]])  ) {
+    stop("Invalid input: pie_size vector must be of length 1 or the same length as the number of sites.")
   }
 
   # Transform admixture data into a plotting format ----
@@ -175,7 +180,7 @@ mapmixture <- function(
 
   # Create a vector of default cluster names if parameter not set
   if (is.null(cluster_names)) {
-    cluster_names <- cluster_col_order
+    cluster_names <- cluster_col_names
   }
 
   # Do these validation checks if basemap object is not NULL
@@ -183,13 +188,8 @@ mapmixture <- function(
 
     # stop if basemap if not a SpatRaster or sf object
     if (!(("SpatRaster" %in% class(basemap)) | ("sf" %in% class(basemap)))) {
-      stop("basemap is not a SpatRaster or sf object. Please use terra::rast() to create a SpatRaster object or sf::st_read() to create a sf object.")
+      stop("Invalid input: basemap is not a SpatRaster or sf object. Please use terra::rast() to create a SpatRaster object or sf::st_read() to create a sf object.")
     }
-
-    # stop if basemap is not a sf object
-    # if (sf::st_crs(basemap) != sf::st_crs(crs)) {
-    #   stop("CRS of basemap object does not match crs argument. Please use terra::project() to transform basemap to the correct CRS.")
-    # }
   }
 
   # Initiate ggplot
@@ -268,23 +268,33 @@ mapmixture <- function(
     )
 
 
-  # Add legend by creating a dummy point data set
+  # Add legend by creating a dummy point data.frame
   legend_data <- data.frame(
     cluster = colnames(admix_coords[4:ncol(admix_coords)]),
     x = rep(NA, length(admix_coords[4:ncol(admix_coords)])),
     y = rep(NA, length(admix_coords[4:ncol(admix_coords)]))
   )
 
-  # Add legend to plot using a dummy point data set (not ideal but works)
+  # GitHub Issue #28
+  # Change cluster column names to custom cluster names if argument supplied
+  if (!is.null(cluster_names)) {
+    if (length(cluster_names) != length(cluster_col_names)) {
+      stop("Invalid input: cluster_names vector must be the same length as the number of clusters.")
+    } else {
+      legend_data$cluster <- cluster_names
+    }
+  }
+
+  # Add legend to plot using a dummy point data (not ideal but works)
   # NOTE: 02/11/2023: The legend key does not resize
   # The only way to resize is to add a guides(fill = guide_legend(override.aes = list(size = 3)))
   plt <- plt+
     ggplot2::geom_point(
       data = legend_data,
       ggplot2::aes(x = !!as.name("x"), y = !!as.name("y"), fill = !!as.name("cluster")),
-      shape = 22, colour = "black", stroke = 0.3, size = 5 * pie_size , alpha = 0
+      shape = 22, colour = "black", stroke = 0.3, size = 5 * min(pie_size) , alpha = 0
     )+
-    ggplot2::scale_fill_manual(values = cluster_cols, labels = stringr::str_to_title(cluster_names))+
+    ggplot2::scale_fill_manual(values = cluster_cols, breaks = cluster_names)+
     ggplot2::theme(
       legend.title = ggplot2::element_blank(),
       legend.key = ggplot2::element_rect(fill = NA),
